@@ -5,17 +5,15 @@
  *
  * Released under the terms of GNU GPL v.2
  * (http://www.gnu.org/licenses/old-licenses/gpl-2.0.html)
- * with the additional exemption that
- * compiling, linking, and/or using OpenSSL is allowed.
- *
- * based on implementation by Finn Yannick Jacobs  Krzysztof Dabrowski, ElysiuM deeZine 
  *
  */
 
 #ifndef _CRC32_H
 #define _CRC32_H
+#include <stdint.h>
 
 void chksum_crc32gentab();
+uint32_t chksum_crc32(unsigned char *block, unsigned int length);
 unsigned char *crc32(unsigned char *block, unsigned int len);
 
 #endif
